summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/timebox.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb570158698cf61dad4f77d950ef908160f6c3cc (patch)
tree649bf182bcf0a20bed5035d25ffd77de5aee138a /kstars/kstars/timebox.h
parentd8762de95349dc6edaa34db9bf699b367c1af6b1 (diff)
downloadtdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.tar.gz
tdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kstars/kstars/timebox.h')
-rw-r--r--kstars/kstars/timebox.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kstars/kstars/timebox.h b/kstars/kstars/timebox.h
index 297b89aa..7e515731 100644
--- a/kstars/kstars/timebox.h
+++ b/kstars/kstars/timebox.h
@@ -38,12 +38,12 @@ class timeBox : public TQLineEdit {
public:
/**
* Constructor for the timeBox object.
* @param tqparent is the tqparent TQWidget
* @param n name is the name of the object
* @param tt boolean. true means that the object will hold a Time.
* false means that the object will hold a Date.
*/
- timeBox(TQWidget *tqparent, const char *n, bool tt=TRUE);
+ timeBox(TQWidget *parent, const char *n, bool tt=TRUE);
~timeBox();
@@ -38,12 +38,12 @@ class timeBox : public TQLineEdit {
/**
* Constructor for the timeBox object.
- * @param tqparent is the tqparent TQWidget
+ * @param parent is the parent TQWidget
* @param n name is the name of the object
* @param tt boolean. true means that the object will hold a Time.